@@ -10,5 +10,5 @@
 openssl::x509_ptr X509Loader::readFromDER(const QByteArray &data)
 {
     const uint8_t *certData = reinterpret_cast<const uint8_t*>(data.constData());
-    return openssl::x509_ptr(d2i_X509(nullptr, &certData, data.size()), &X509_free);
+    return openssl::x509_ptr(d2i_X509(nullptr, &certData, data.size()));
 }
